# Dataset of intraoperative pre- and post-resection ECoG recorded from epilepsy patients and fast ripple (FR) markings

## Summary
We present an electrophysiological dataset recorded from twenty-two subjects during resective epilepsy surgery. We used standard electrodes with 10 mm inter-contact spacing (standard ECoG) in 14 surgeries and high-density grid electrodes with 5 mm spacing (hd-ECoG) in 8 surgeries. We recorded ECoG pre- and post-resection. We detected fast ripples (FR) using a previously validated automatic detector and did visual validation. For each recording, we provide the recorded data and FR markings. We also provide the approximate locations of recordings and resected area. The data was used in our publication "High-density ECoG improves the detection of high frequency oscillations that predict seizure outcome" (doi.org/10.1016/j.clinph.2019.07.008).

## Downloading the data

### Using gin

Create an account on gin and download the *gin* client as described [here](https://web.gin.g-node.org/G-Node/Info/wiki/gin-cli). On your computer, log in using
```bash
gin login
```

Clone the repository using:
```bash
gin get USZ_NCH/Intraoperative_ECoG_HFO    
```

Large data files will not be downloaded automatically. To get them, use
```bash
gin get-content <filename>
```

Downloaded large files will be locked (read-only). You must unlock the files using
```bash
gin unlock <filename>
```

To remove the contents of a large file again, use
```bash
gin lock <filename>
gin remove-content <filename>
```

See [here](https://web.gin.g-node.org/G-Node/Info/wiki/gin-cli+tutorial) for detailed information on how to use *gin*.


### Using git annex

Make sure git and git-annex are installed on your computer. Create an account on gin and upload your public SSH key to your gin profile. Then clone the repository using
```bash
git clone git@gin.g-node.org:/USZ_NCH/Intraoperative_ECoG_HFO .git
```

Large data files will not be downloaded automatically. To get them, use
```bash
git annex get <filename>
```

Downloaded large files will be locked (read-only). You must unlock the files using
```bash
git annex unlock <filename>
```

To remove the contents of a large file again, use
```bash
git annex --force lock <filename>
git annex drop <filename>
```

See the *git annex* documentation for details.


### Using the web browser

Download the latest release as a zip file by clicking on *Releases* on the main page at https://gin.g-node.org/USZ_NCH/Intraoperative_ECoG_HFO . This zip file will contain all small (text) files only, while large data files will not be downloaded automatically and an empty placeholder will be put in their place. To get the full content of such a large file , download these files individually as needed from the web interface by clicking on them in the repository browser.

## Updates
Updated versions of the codes will be provided at:
https://gin.g-node.org/USZ_NCH/Intraoperative_ECoG_HFO 

## Related Publications
* Boran E, Ramantani G, Krayenbuhl N, Schreiber M, Konig K, Fedele T, Sarnthein J. High-density ECoG improves the detection of high frequency oscillations that predict seizure outcome. Clin Neurophysiol 2019;130(10):1882-8. https://doi.org/10.1016/j.clinph.2019.07.008.
* Boran Ece, Sarnthein J, Krayenbühl N, Ramantani G, Fedele T. High-frequency oscillations in scalp EEG mirror seizure frequency in pediatric focal epilepsy. Sci Rep.	
* Fedele T, Burnos S, Boran E, Krayenbuhl N, Hilfiker P, Grunwald T, Sarnthein J. Resection of high frequency oscillations predicts seizure outcome in the individual patient. Sci Rep 2017;7(1):13836. https://doi.org/10.1038/s41598-017-13064-1.
* Fedele T, Ramantani G, Burnos S, Hilfiker P, Curio G, Grunwald T, Krayenbühl N, Sarnthein J. Prediction of seizure outcome improved by fast ripples detected in low-noise intraoperative corticogram. Clin Neurophysiol 2017;128(7):1220-6. https://doi.org/10.1016/j.clinph.2017.03.038.
* Fedele T, van 't Klooster M, Burnos S, Zweiphenning W, van Klink N, Leijten F, Zijlmans M, Sarnthein J. Automatic detection of high frequency oscillations during epilepsy surgery predicts seizure outcome. Clin Neurophysiol 2016;127(9):3066-74. https://doi.org/10.1016/j.clinph.2016.06.009.
	
	
## Licensing
<a rel="license" href="https://creativecommons.org/licenses/by-sa/4.0/"><img alt="Creative Commons License" style="border-width:0" src="https://i.creativecommons.org/l/by-sa/4.0/88x31.png" /></a><br />This work is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by-sa/4.0/">Creative Commons Attribution-ShareAlike 4.0 International License</a>.

See `LICENSE.txt` for the full license.